Model

Struct Model 

pub struct Model {
    pub blink_speed: Duration,
    pub style: Style,
    pub text_style: Style,
    /* private fields */
}
Model is the Bubble Tea model for this cursor element.

Fields

blink_speed: Duration

The speed at which the cursor blinks.

style: Style

Style for the cursor when it is visible (blinking “on”).

text_style: Style

Style for the text under the cursor when it is hidden (blinking “off”).

Implementations

Source

impl Model

pub fn new() -> Self

Creates a new model with default settings.

pub fn set_visible(&mut self, visible: bool)

Sets the visibility of the cursor.

pub fn update(&mut self, msg: &Msg) -> Option<Cmd>

Update is the Bubble Tea update loop. It handles cursor-related messages. This is not a bubbletea_rs::Model implementation because the cursor is a sub-component managed by another model.

pub fn mode(&self) -> Mode

Returns the model’s cursor mode.

pub fn set_mode(&mut self, mode: Mode) -> Option<Cmd>

Sets the model’s cursor mode. This method returns a command.

pub fn focus(&mut self) -> Option<Cmd>

Focuses the cursor to allow it to blink if desired.

pub fn blur(&mut self)

Blurs the cursor.

pub fn focused(&self) -> bool

Check if cursor is focused

pub fn set_char(&mut self, s: &str)

Sets the character under the cursor.

pub fn view(&self) -> String

Renders the cursor.