pub fn with_help(
key: impl Into<String> + 'static,
desc: impl Into<String> + 'static,
) -> BindingOptExpand description
Creates a binding option that sets the help text.
This function provides Go-style WithHelp functionality for setting
the help text that will be displayed in help views.
Arguments
key- The human-readable key representation for help displaydesc- A brief description of what the binding does
Examples
use bubbletea_widgets::key::{new_binding, with_keys_str, with_help};
let binding = new_binding(vec![
with_keys_str(&["ctrl+s"]),
with_help("ctrl+s", "Save the current file"),
]);