pub enum SpinnerOption {
WithSpinner(Spinner),
WithStyle(Box<Style>),
}Expand description
Configuration option for creating a new spinner with custom settings.
SpinnerOption implements the options pattern used by the new() function
to configure spinner instances. This matches Go’s functional options pattern
used in the original bubbles library.
Variants
WithSpinner(Spinner)- Sets the animation frames and timingWithStyle(Style)- Sets the lipgloss styling
Examples
use bubbletea_widgets::spinner::{new, with_spinner, with_style, DOT};
use lipgloss_extras::prelude::*;
let spinner = new(&[
with_spinner(DOT.clone()),
with_style(Style::new().foreground(Color::from("red")))
]);Variants
WithSpinner(Spinner)
Sets the animation frames and timing to use.
WithStyle(Box<Style>)
Sets the lipgloss style for rendering the spinner.