with_focused

Function with_focused 

pub fn with_focused(f: bool) -> TableOption
Creates an option to set table focus state during construction.

This option configures whether the table should be focused (and thus respond to keyboard input) when initially created.

Arguments

  • f - true for focused, false for unfocused

Examples

use bubbletea_widgets::table::{Model, with_focused};

let table = Model::with_options(vec![
    with_focused(false),
]);
assert!(!table.focus);