TextareaKeyMap

Struct TextareaKeyMap 

pub struct TextareaKeyMap {
Show 22 fields pub character_backward: Binding, pub character_forward: Binding, pub delete_after_cursor: Binding, pub delete_before_cursor: Binding, pub delete_character_backward: Binding, pub delete_character_forward: Binding, pub delete_word_backward: Binding, pub delete_word_forward: Binding, pub insert_newline: Binding, pub line_end: Binding, pub line_next: Binding, pub line_previous: Binding, pub line_start: Binding, pub paste: Binding, pub word_backward: Binding, pub word_forward: Binding, pub input_begin: Binding, pub input_end: Binding, pub uppercase_word_forward: Binding, pub lowercase_word_forward: Binding, pub capitalize_word_forward: Binding, pub transpose_character_backward: Binding,
}
Complete KeyMap for textarea component - direct port from Go

Fields

character_backward: Binding

Move cursor one character left.

character_forward: Binding

Move cursor one character right.

delete_after_cursor: Binding

Delete from cursor to end of line.

delete_before_cursor: Binding

Delete from start of line to cursor.

delete_character_backward: Binding

Delete one character backward.

delete_character_forward: Binding

Delete one character forward.

delete_word_backward: Binding

Delete previous word.

delete_word_forward: Binding

Delete next word.

insert_newline: Binding

Insert newline.

line_end: Binding

Move cursor to end of line.

line_next: Binding

Move cursor to next visual line.

line_previous: Binding

Move cursor to previous visual line.

line_start: Binding

Move cursor to start of line.

paste: Binding

Paste from clipboard.

word_backward: Binding

Move one word left.

word_forward: Binding

Move one word right.

input_begin: Binding

Move to beginning of input.

input_end: Binding

Move to end of input.

uppercase_word_forward: Binding

Uppercase the word to the right of the cursor.

lowercase_word_forward: Binding

Lowercase the word to the right of the cursor.

capitalize_word_forward: Binding

Capitalize the word to the right of the cursor.

transpose_character_backward: Binding

Transpose the character to the left with the current one.