Module keymap

Module keymap 

Key bindings for the textinput component.

Structs

KeyMap
KeyMap is the key bindings for different actions within the textinput. Matches Go’s KeyMap struct exactly.

Functions

default_key_map
DefaultKeyMap is the default set of key bindings for navigating and acting upon the textinput. Matches Go’s DefaultKeyMap exactly.