Function blink

pub fn blink() -> Cmd
Creates a command that triggers cursor blinking.

This command should be returned from your application’s init() method or when focusing the text input to start the cursor blinking animation.

Returns

A Cmd that will periodically send blink messages to animate the cursor

Examples

use bubbletea_widgets::textinput::blink;
use bubbletea_rs::{Model, Cmd};

struct App {
    // ... other fields
}

impl Model for App {
    fn init() -> (Self, Option<Cmd>) {
        // Return blink command to start cursor animation
        (App { /* ... */ }, Some(blink()))
    }
}