pub struct Model {
pub blink_speed: Duration,
pub style: Style,
pub text_style: Style,
/* private fields */
}Expand description
Model is the Bubble Tea model for this cursor element.
Fields
blink_speed: DurationThe speed at which the cursor blinks.
style: StyleStyle for the cursor when it is visible (blinking “on”).
text_style: StyleStyle for the text under the cursor when it is hidden (blinking “off”).
Implementations
Sourceimpl Model
impl Model
Sourcepub fn set_visible(&mut self, visible: bool)
pub fn set_visible(&mut self, visible: bool)
Sets the visibility of the cursor.
Sourcepub fn update(&mut self, msg: &Msg) -> Option<Cmd>
pub fn update(&mut self, msg: &Msg) -> Option<Cmd>
Update is the Bubble Tea update loop. It handles cursor-related messages.
This is not a bubbletea_rs::Model implementation because the cursor is
a sub-component managed by another model.