pub struct Styles {
pub disabled_cursor: Style,
pub cursor: Style,
pub symlink: Style,
pub directory: Style,
pub file: Style,
pub disabled_file: Style,
pub permission: Style,
pub selected: Style,
pub disabled_selected: Style,
pub file_size: Style,
pub empty_directory: Style,
}Expand description
Visual styling configuration for the file picker.
This struct allows customization of colors and styles for different elements of the file picker interface, including the cursor, directories, files, and selected items.
Examples
use bubbletea_widgets::filepicker::Styles;
use lipgloss_extras::prelude::*;
let mut styles = Styles::default();
styles.cursor = Style::new().foreground(Color::from("cyan"));
styles.directory = Style::new().foreground(Color::from("blue")).bold(true);Fields
disabled_cursor: StyleStyle for the cursor when disabled. Default: foreground color 247 (gray)
cursor: StyleStyle for the cursor indicator (usually “> “). Default: foreground color 212 (pink/magenta)
symlink: StyleStyle for symlink file names. Default: foreground color 36 (cyan)
directory: StyleStyle for directory names in the file list. Default: foreground color 99 (purple)
file: StyleStyle for regular file names in the file list. Default: no special styling (terminal default)
disabled_file: StyleStyle for disabled/unselectable files. Default: foreground color 243 (dark gray)
permission: StyleStyle for file permissions display. Default: foreground color 244 (gray)
selected: StyleStyle applied to the currently selected item (in addition to file/directory style). Default: foreground color 212 (pink/magenta) and bold
disabled_selected: StyleStyle for disabled selected items. Default: foreground color 247 (gray)
file_size: StyleStyle for file size display. Default: foreground color 240 (dark gray), right-aligned
empty_directory: StyleStyle for empty directory message. Default: foreground color 240 (dark gray) with left padding