Module help

A help component for bubbletea-rs, ported from the Go version.

This component provides a customizable help view that can automatically generate its content from a set of key bindings.

Structs

Model
The help model that manages help view state and rendering.
Styles
A set of styles for the help component.

Traits

KeyMap
A trait that defines the key bindings to be displayed in the help view.