Struct ListStyles

pub struct ListStyles {
Show 17 fields pub title_bar: Style, pub title: Style, pub spinner: Style, pub filter_prompt: Style, pub filter_cursor: Style, pub default_filter_character_match: Style, pub status_bar: Style, pub status_empty: Style, pub status_bar_active_filter: Style, pub status_bar_filter_count: Style, pub no_items: Style, pub pagination_style: Style, pub help_style: Style, pub active_pagination_dot: Style, pub inactive_pagination_dot: Style, pub arabic_pagination: Style, pub divider_dot: Style,
}
Collection of styles applied to list UI elements.

Fields

title_bar: Style

Style for the title bar container.

title: Style

Style for the list title text.

spinner: Style

Style for spinner glyphs.

filter_prompt: Style

Style for the filter prompt label.

filter_cursor: Style

Style for the filter cursor/caret.

default_filter_character_match: Style

Style for default filter character highlight.

status_bar: Style

Style for the status bar container.

status_empty: Style

Style for the status bar when the list is empty.

status_bar_active_filter: Style

Style for active filter text in the status bar.

status_bar_filter_count: Style

Style for filter match count in the status bar.

no_items: Style

Style for the “No items” message.

pagination_style: Style

Style for pagination area.

help_style: Style

Style for help text area.

active_pagination_dot: Style

Style for the active pagination dot.

inactive_pagination_dot: Style

Style for the inactive pagination dot.

arabic_pagination: Style

Style for arabic numerals in pagination.

divider_dot: Style

Style for the divider dot between elements.