pub type TableOption = Box<dyn FnOnce(&mut Model) + Send>;Expand description
Configuration option for table construction.
This type enables the flexible option-based constructor pattern used by the Go version. Each option is a function that modifies a table model during construction, allowing for clean, composable configuration.
Examples
use bubbletea_widgets::table::{Model, TableOption, with_columns, with_rows, with_height, Column, Row};
let table = Model::with_options(vec![
with_columns(vec![Column::new("Name", 20)]),
with_rows(vec![Row::new(vec!["Alice".into()])]),
with_height(15),
]);Aliased Type
pub struct TableOption(/* private fields */);