pub struct TextareaKeyMap {Show 22 fields
pub character_backward: Binding,
pub character_forward: Binding,
pub delete_after_cursor: Binding,
pub delete_before_cursor: Binding,
pub delete_character_backward: Binding,
pub delete_character_forward: Binding,
pub delete_word_backward: Binding,
pub delete_word_forward: Binding,
pub insert_newline: Binding,
pub line_end: Binding,
pub line_next: Binding,
pub line_previous: Binding,
pub line_start: Binding,
pub paste: Binding,
pub word_backward: Binding,
pub word_forward: Binding,
pub input_begin: Binding,
pub input_end: Binding,
pub uppercase_word_forward: Binding,
pub lowercase_word_forward: Binding,
pub capitalize_word_forward: Binding,
pub transpose_character_backward: Binding,
}Expand description
Complete KeyMap for textarea component - direct port from Go
Fields
character_backward: BindingMove cursor one character left.
character_forward: BindingMove cursor one character right.
delete_after_cursor: BindingDelete from cursor to end of line.
delete_before_cursor: BindingDelete from start of line to cursor.
delete_character_backward: BindingDelete one character backward.
delete_character_forward: BindingDelete one character forward.
delete_word_backward: BindingDelete previous word.
delete_word_forward: BindingDelete next word.
insert_newline: BindingInsert newline.
line_end: BindingMove cursor to end of line.
line_next: BindingMove cursor to next visual line.
line_previous: BindingMove cursor to previous visual line.
line_start: BindingMove cursor to start of line.
paste: BindingPaste from clipboard.
word_backward: BindingMove one word left.
word_forward: BindingMove one word right.
input_begin: BindingMove to beginning of input.
input_end: BindingMove to end of input.
uppercase_word_forward: BindingUppercase the word to the right of the cursor.
lowercase_word_forward: BindingLowercase the word to the right of the cursor.
capitalize_word_forward: BindingCapitalize the word to the right of the cursor.
transpose_character_backward: BindingTranspose the character to the left with the current one.