pub struct Model {
pub err: Option<String>,
pub prompt: String,
pub placeholder: String,
pub show_line_numbers: bool,
pub end_of_buffer_character: char,
pub key_map: TextareaKeyMap,
pub focused_style: TextareaStyle,
pub blurred_style: TextareaStyle,
pub cursor: Model,
pub char_limit: usize,
pub max_height: usize,
pub max_width: usize,
/* private fields */
}Expand description
Model is the Bubble Tea model for this text area element. Direct port from Go’s Model struct with all fields preserved
Fields
err: Option<String>Optional error string surfaced by the component.
prompt: StringPrompt is printed at the beginning of each line
placeholder: StringPlaceholder is the text displayed when the user hasn’t entered anything yet
show_line_numbers: boolShowLineNumbers, if enabled, causes line numbers to be printed after the prompt
end_of_buffer_character: charEndOfBufferCharacter is displayed at the end of the input
key_map: TextareaKeyMapKey bindings recognized by the widget.
focused_style: TextareaStyleStyle used when the textarea is focused.
blurred_style: TextareaStyleStyle used when the textarea is blurred.
cursor: ModelEmbedded cursor model for caret rendering and blinking.
char_limit: usizeCharLimit is the maximum number of characters this input element will accept
max_height: usizeMaxHeight is the maximum height of the text area in rows
max_width: usizeMaxWidth is the maximum width of the text area in columns
Implementations
Sourceimpl Model
impl Model
Sourcepub fn set_value(&mut self, s: impl Into<String>)
pub fn set_value(&mut self, s: impl Into<String>)
Set the value of the text input - port of Go’s SetValue
Sourcepub fn insert_string(&mut self, s: impl Into<String>)
pub fn insert_string(&mut self, s: impl Into<String>)
Insert a string at the cursor position - port of Go’s InsertString
Sourcepub fn insert_rune(&mut self, r: char)
pub fn insert_rune(&mut self, r: char)
Insert a rune at the cursor position - port of Go’s InsertRune
Sourcepub fn length(&self) -> usize
pub fn length(&self) -> usize
Length returns the number of characters currently in the text input - port of Go’s Length()
Sourcepub fn line_count(&self) -> usize
pub fn line_count(&self) -> usize
LineCount returns the number of lines currently in the text input - port of Go’s LineCount()
Sourcepub fn focused(&self) -> bool
pub fn focused(&self) -> bool
Focused returns the focus state on the model - port of Go’s Focused()
Sourcepub fn reset(&mut self)
pub fn reset(&mut self)
Reset sets the input to its default state with no input - port of Go’s Reset()
Sourcepub fn height(&self) -> usize
pub fn height(&self) -> usize
Height returns the current height of the textarea - port of Go’s Height()
Sourcepub fn set_width(&mut self, w: usize)
pub fn set_width(&mut self, w: usize)
SetWidth sets the width of the textarea - port of Go’s SetWidth()
Sourcepub fn set_height(&mut self, h: usize)
pub fn set_height(&mut self, h: usize)
SetHeight sets the height of the textarea - port of Go’s SetHeight()
Sourcepub fn set_prompt_func(
&mut self,
prompt_width: usize,
func: fn(usize) -> String,
)
pub fn set_prompt_func( &mut self, prompt_width: usize, func: fn(usize) -> String, )
SetPromptFunc supersedes the Prompt field and sets a dynamic prompt instead Port of Go’s SetPromptFunc
Sourcepub fn set_cursor(&mut self, col: usize)
pub fn set_cursor(&mut self, col: usize)
SetCursor moves the cursor to the given position - port of Go’s SetCursor()
Sourcepub fn cursor_start(&mut self)
pub fn cursor_start(&mut self)
CursorStart moves the cursor to the start of the input field - port of Go’s CursorStart()
Sourcepub fn cursor_end(&mut self)
pub fn cursor_end(&mut self)
CursorEnd moves the cursor to the end of the input field - port of Go’s CursorEnd()
Sourcepub fn cursor_down(&mut self)
pub fn cursor_down(&mut self)
CursorDown moves the cursor down by one line - port of Go’s CursorDown()
Sourcepub fn move_to_begin(&mut self)
pub fn move_to_begin(&mut self)
Move to the beginning of input - port of Go’s moveToBegin()
Sourcepub fn move_to_end(&mut self)
pub fn move_to_end(&mut self)
Move to the end of input - port of Go’s moveToEnd()
Sourcepub fn line_info(&mut self) -> LineInfo
pub fn line_info(&mut self) -> LineInfo
LineInfo returns line information for the current cursor position Port of Go’s LineInfo() - enhanced with better wrapped line handling
Sourcepub fn delete_before_cursor(&mut self)
pub fn delete_before_cursor(&mut self)
Delete before cursor - port of Go’s deleteBeforeCursor()
Sourcepub fn delete_after_cursor(&mut self)
pub fn delete_after_cursor(&mut self)
Delete after cursor - port of Go’s deleteAfterCursor()
Sourcepub fn delete_character_backward(&mut self)
pub fn delete_character_backward(&mut self)
Delete character backward - port of Go’s deleteCharacterBackward()
Sourcepub fn delete_character_forward(&mut self)
pub fn delete_character_forward(&mut self)
Delete character forward - port of Go’s deleteCharacterForward()
Sourcepub fn delete_word_backward(&mut self)
pub fn delete_word_backward(&mut self)
Delete word backward - port of Go’s deleteWordLeft()
Sourcepub fn delete_word_forward(&mut self)
pub fn delete_word_forward(&mut self)
Delete word forward - port of Go’s deleteWordRight()
Sourcepub fn insert_newline(&mut self)
pub fn insert_newline(&mut self)
Insert newline - port of Go’s InsertNewline()
Sourcepub fn character_left(&mut self, inside_line: bool)
pub fn character_left(&mut self, inside_line: bool)
Move cursor one character left - port of Go’s characterLeft()
Sourcepub fn character_right(&mut self)
pub fn character_right(&mut self)
Move cursor one character right - port of Go’s characterRight()
Sourcepub fn word_right(&mut self)
pub fn word_right(&mut self)
Move cursor one word right - port of Go’s wordRight()
Sourcepub fn uppercase_right(&mut self)
pub fn uppercase_right(&mut self)
Transform word to uppercase - port of Go’s uppercaseRight()
Sourcepub fn lowercase_right(&mut self)
pub fn lowercase_right(&mut self)
Transform word to lowercase - port of Go’s lowercaseRight()
Sourcepub fn capitalize_right(&mut self)
pub fn capitalize_right(&mut self)
Transform word to title case - port of Go’s capitalizeRight()
Sourcepub fn transpose_left(&mut self)
pub fn transpose_left(&mut self)
Transpose characters - port of Go’s transposeLeft()
Sourcepub fn scroll_down(&mut self, lines: usize)
pub fn scroll_down(&mut self, lines: usize)
Scroll viewport down by n lines - for testing viewport functionality
Sourcepub fn scroll_up(&mut self, lines: usize)
pub fn scroll_up(&mut self, lines: usize)
Scroll viewport up by n lines - for testing viewport functionality
Sourcepub fn cursor_line_number(&mut self) -> usize
pub fn cursor_line_number(&mut self) -> usize
Get cursor line number for display - port of Go’s cursorLineNumber()
Sourcepub fn update(&mut self, msg: Option<Msg>) -> Option<Cmd>
pub fn update(&mut self, msg: Option<Msg>) -> Option<Cmd>
Update handles incoming messages and updates the textarea state - port of Go’s Update()
Sourcepub fn copy_to_clipboard(&self, text: &str) -> Result<(), String>
pub fn copy_to_clipboard(&self, text: &str) -> Result<(), String>
Copy text to system clipboard
Sourcepub fn copy_selection(&self) -> Result<(), String>
pub fn copy_selection(&self) -> Result<(), String>
Copy current selection to clipboard (if selection is implemented)
Sourcepub fn cut_selection(&mut self) -> Result<(), String>
pub fn cut_selection(&mut self) -> Result<(), String>
Cut current selection to clipboard (if selection is implemented)