Module model
bubbletea_
widgets
0.1.12
Module model
Module Items
Structs
Functions
In bubbletea_
widgets::
textinput
bubbletea_widgets
::
textinput
Module
model
Core model implementation for the textinput component.
Structs

Model
The main text input component model for Bubble Tea applications.
Functions

blink
Creates a command that triggers cursor blinking.
new
Creates a new text input model with default settings.
new_
model
Creates a new text input model (alias for
new()
).
paste
Creates a command that retrieves text from the system clipboard.